==> ruby1.9_1.9.0+20070830.orig.tar.gz: ruby1.9-1.9.0+20070830.orig/test/scanf/test_scanfblocks.rb <==
# $Id: test_scanfblocks.rb 11708 2007-02-12 23:01:19Z shyouhei $
#
# scanf for Ruby
#
# Some not very comprehensive tests of block behavior.


require 'test/unit'
require 'scanf'

class TestScanfBlock < Test::Unit::TestCase

  def setup
    @str = <<-EOS
    Beethoven  1770
    Bach       1685
    Handel     1685
    Scarlatti  1685
    Brahms     1833
    EOS
  end
  
alias set_up setup
  def test_str1
    res = @str.scanf("%s%d") { |name, year| "#{name} was born in #{year}." }
    assert_equal(res,
    [ "Beethoven was born in 1770.",
      "Bach was born in 1685.",
      "Handel was born in 1685.",
      "Scarlatti was born in 1685.",
      "Brahms was born in 1833." ])
  end

  def test_str2
    names = @str.scanf("%s%d") { |name, year| name.upcase }
    assert_equal(names, ["BEETHOVEN", "BACH", "HANDEL", "SCARLATTI", "BRAHMS"])
  end

  def test_str3
    assert_equal("".scanf("%d%f%s") {}, [])
  end

  def test_str4
    assert_equal("abc".scanf("%d%f%s") {}, [])
  end

  def test_str5
    assert_equal("abc".scanf("") {}, [])
  end

  def test_io1
    File.open("iotest.dat", "w") { |fh| fh.puts(@str) }
    fh = File.open("iotest.dat", "rb")
    res = fh.scanf("%s%d") { |name, year| "#{name} was born in #{year}." }

    assert_equal(
    [ "Beethoven was born in 1770.",
      "Bach was born in 1685.",
      "Handel was born in 1685.",
      "Scarlatti was born in 1685.",
      "Brahms was born in 1833." ],res)
    fh.close
  ensure
    File.delete("iotest.dat")  
    end

  def test_io2
    File.open("iotest.dat", "w").close
    fh = File.open("iotest.dat","rb")
    assert_equal(fh.scanf("") {}, [])
    fh.seek(0)
    assert_equal(fh.scanf("%d%f%s") {}, [])
    fh.close
  ensure
    File.delete("iotest.dat")  
  end

end

==> ruby-2.1.8.tar.gz: ruby-2.1.8/test/scanf/test_scanfblocks.rb <==
# $Id: test_scanfblocks.rb 25189 2009-10-02 12:04:37Z akr $
#
# scanf for Ruby
#
# Some not very comprehensive tests of block behavior.


require 'test/unit'
require 'scanf'
require 'tmpdir'

class TestScanfBlock < Test::Unit::TestCase

  def setup
    @str = <<-EOS
    Beethoven  1770
    Bach       1685
    Handel     1685
    Scarlatti  1685
    Brahms     1833
    EOS
  end

alias set_up setup
  def test_str1
    res = @str.scanf("%s%d") { |name, year| "#{name} was born in #{year}." }
    assert_equal(res,
    [ "Beethoven was born in 1770.",
      "Bach was born in 1685.",
      "Handel was born in 1685.",
      "Scarlatti was born in 1685.",
      "Brahms was born in 1833." ])
  end

  def test_str2
    names = @str.scanf("%s%d") { |name, year| name.upcase }
    assert_equal(names, ["BEETHOVEN", "BACH", "HANDEL", "SCARLATTI", "BRAHMS"])
  end

  def test_str3
    assert_equal("".scanf("%d%f%s") {}, [])
  end

  def test_str4
    assert_equal("abc".scanf("%d%f%s") {}, [])
  end

  def test_str5
    assert_equal("abc".scanf("") {}, [])
  end

  def test_io1
    fn = "#{Dir.tmpdir}/iotest.dat.#{$$}"
    File.open(fn, "w") { |fh| fh.puts(@str) }
    fh = File.open(fn, "rb")
    res = fh.scanf("%s%d") { |name, year| "#{name} was born in #{year}." }

    assert_equal(
    [ "Beethoven was born in 1770.",
      "Bach was born in 1685.",
      "Handel was born in 1685.",
      "Scarlatti was born in 1685.",
      "Brahms was born in 1833." ],res)
    fh.close
  ensure
    File.delete(fn)
  end

  def test_io2
    fn = "#{Dir.tmpdir}/iotest.dat.#{$$}"
    File.open(fn, "w").close
    fh = File.open(fn,"rb")
    assert_equal(fh.scanf("") {}, [])
    fh.seek(0)
    assert_equal(fh.scanf("%d%f%s") {}, [])
    fh.close
  ensure
    File.delete(fn)
  end

end
